
public
class CommPort {

    /**
     * Link in the native library that we depend on.  If we cannot
     * link this in, an exception is generated and the class loading
     * fails. We have arbitrarily named the library "file" at the
     * Java level (or libfile.so at the solaris level). Additionally,
     * the System call is part of the static initializer for the class.
     * Thus, the library is loaded as part of this class being loaded.
     */
    static {
	try {
            System.loadLibrary("comm");
	} catch (UnsatisfiedLinkError e) {
            System.out.println("Could not load comm.dll");
            System.exit(-1);
        }

    }

    /**
     * The comm port opened
     */
    //protected int commId;

    /**
     * Constructor for the Comm port.
     */
    public CommPort(int commId) {
		open( commId );
	}

    /**
     * Attempts to open the file for reading. Returns
     * TRUE on success and FALSE on failure. Alternatively, we could
     * throw an exception and catch it.
     */
    public native boolean open( int commId );

    /**
     * Attempts to close the previously opened file. Has
     * no return value.
     */
    public native void close();

	public native void startUp();

    /**
     * Reads some number of bytes from the opened file. Returns
     * the number of bytes read or -1 when the file is empty.
     */
    public native int read(byte b[], int len);

    /**
     * Reads a single byte, returns -1 when file is empty.
	 */
    public native int readByte();
  
}
